@@ -4,10 +4,8 @@ import re
 # Relationship types
 ONE_TO_ONE = 'one_to_one'
 ONE_TO_MANY = 'one_to_many'
-MANY_TO_ONE = 'many_to_one'
 
 RELATIONSHIP_TYPES = [
-    MANY_TO_ONE,
     ONE_TO_MANY,
     ONE_TO_ONE,
 ]
@@ -35,11 +33,19 @@ NODE_ATTRIBUTES = [
 
 # Relationship attributes
 RELATIONSHIP_ATTRIBUTES = [
+    'foreign_key',
     'through_tables',
     'type',
     'variant',
 ]
 
+# Relationship foreign keys
+RELATIONSHIP_FOREIGN_KEYS = [
+     'child',
+     'parent',
+]
+
+
 # tg_op
 UPDATE = 'UPDATE'
 INSERT = 'INSERT'
@@ -53,6 +59,14 @@ TG_OP = [
     UPDATE,
 ]
 
+# https://www.postgresql.org/docs/current/functions-json.html
+JSONB_OPERATORS = [
+    '->',
+    '->>',
+    '#>',
+    '#>>',
+]
+
 # https://www.elastic.co/guide/en/elasticsearch/reference/current/sql-data-types.html
 ELASTICSEARCH_TYPES = [
     'binary',
@@ -60,31 +74,51 @@ ELASTICSEARCH_TYPES = [
     'byte',
     'constant_keyword',
     'date',
+    'date',
     'double',
     'float',
+    'geo_point',
+    'geo_shape',
     'half_float',
     'integer',
+    'interval_day',
+    'interval_day_to_hour',
+    'interval_day_to_minute',
+    'interval_day_to_second',
+    'interval_hour',
+    'interval_hour_to_minute',
+    'interval_hour_to_second',
+    'interval_minute',
+    'interval_minute_to_second',
+    'interval_month',
+    'interval_second',
+    'interval_year',
+    'interval_year_to_month',
     'ip',
     'keyword',
     'long',
+    'nested',
     'null',
+    'object',
     'scaled_float',
+    'shape',
     'short',
     'text',
-    'object',
-    'nested',
+    'time',
 ]
 
 CONCAT_TRANSFORM = 'concat'
 MAPPING_TRANSFORM = 'mapping'
 MOVE_TRANSFORM = 'move'
 RENAME_TRANSFORM = 'rename'
+REPLACE_TRANSFORM = 'replace'
 
 TRANSFORM_TYPES = [
     CONCAT_TRANSFORM,
     MAPPING_TRANSFORM,
     MOVE_TRANSFORM,
     RENAME_TRANSFORM,
+    REPLACE_TRANSFORM,
 ]
 
 # default postgres schema
@@ -109,5 +143,5 @@ LOGICAL_SLOT_PREFIX = re.compile(
     r'table\s(?P<schema>\w+).\"?(?P<table>\w+)\"?:\s(?P<tg_op>[A-Z]+):'
 )
 LOGICAL_SLOT_SUFFIX = re.compile(
-    "\s(?P<key>\w+)\[(?P<type>[\w\s]+)\]:(?P<value>[\w\'\"\-]+)"
+    "\s(?P<key>\"?\w+\"?)\[(?P<type>[\w\s]+)\]:(?P<value>[\w\'\"\-]+)"
 )
