@@ -18,7 +18,7 @@ import psycopg2
 import sqlalchemy as sa
 
 from . import __version__
-from .base import Base, compiled_query, get_foreign_keys, get_primary_keys
+from .base import Base, compiled_query, get_primary_keys
 from .constants import (
     DELETE,
     INSERT,
@@ -32,18 +32,16 @@ from .constants import (
 from .elastichelper import ElasticHelper
 from .exc import RDSError, SuperUserError
 from .node import traverse_breadth_first, traverse_post_order, Tree
+from .plugin import Plugins
 from .querybuilder import QueryBuilder
 from .redisqueue import RedisQueue
-from .settings import POLL_TIMEOUT, REPLICATION_SLOT_CLEANUP_INTERVAL
-from .utils import (
-    get_config,
-    get_private_keys,
-    progress,
-    show_settings,
-    threaded,
-    Timer,
-    transform,
+from .settings import (
+    POLL_TIMEOUT,
+    REDIS_POLL_INTERVAL,
+    REPLICATION_SLOT_CLEANUP_INTERVAL,
 )
+from .transform import get_private_keys, transform
+from .utils import get_config, progress, show_settings, threaded, Timer
 
 logger = logging.getLogger(__name__)
 
@@ -61,6 +59,8 @@ class Sync(Base):
         """Constructor."""
         params = params or {}
         self.index = document['index']
+        self.pipeline = document.get('pipeline')
+        self.plugins = document.get('plugins', [])
         self.nodes = document.get('nodes', [])
         self.setting = document.get('setting')
         super().__init__(document.get('database', self.index), **params)
@@ -69,6 +69,7 @@ class Sync(Base):
             '[^0-9a-zA-Z_]+', '', f"{self.database}_{self.index}"
         )
         self._checkpoint = None
+        self._plugins = None
         self._truncate = False
         self.verbose = verbose
         self._checkpoint_file = f".{self.__name}"
@@ -83,6 +84,8 @@ class Sync(Base):
     def validate(self):
         """Perform all validation right away."""
         self.connect()
+        if self.plugins:
+            self._plugins = Plugins('plugins', self.plugins)
 
         max_replication_slots = self.pg_settings('max_replication_slots')
         try:
@@ -143,7 +146,7 @@ class Sync(Base):
             tables = set([])
             root = self.tree.build(self.nodes[0])
             for node in traverse_breadth_first(root):
-                tables |= set(node.through_tables)
+                tables |= set(node.relationship.through_tables)
                 tables |= set([node.table])
             self.create_triggers(self.database, schema, tables=tables)
         self.create_replication_slot(self.__name)
@@ -160,7 +163,7 @@ class Sync(Base):
             tables = set([])
             root = self.tree.build(self.nodes[0])
             for node in traverse_breadth_first(root):
-                tables |= set(node.through_tables)
+                tables |= set(node.relationship.through_tables)
                 tables |= set([node.table])
             self.drop_triggers(self.database, schema=schema, tables=tables)
         self.drop_replication_slot(self.__name)
@@ -364,29 +367,21 @@ class Sync(Base):
 
                         if not node.parent:
                             logger.exception(
-                                f'Could not get parent from node: '
-                                f'{node.schema}.{node.table}'
+                                f'Could not get parent from node: {node.name}'
                             )
                             raise
                         # set the parent as the new entity that has changed
                         filters[node.parent.table] = []
-                        parent_model = self.model(
+                        foreign_keys = self.query_builder._get_foreign_keys(
+                            node.parent,
+                            node,
+                        )
+
+                        _table = self._get_table(schema, table)
+                        node_parent_table = self._get_table(
+                            schema,
                             node.parent.table,
-                            node.parent.schema,
                         )
-                        foreign_keys = get_foreign_keys(
-                            parent_model,
-                            model,
-                        )
-
-                        _table = table
-                        if not _table.startswith(f'{schema}.'):
-                            _table = f'{schema}.{table}'
-
-                        node_parent_table = node.parent.table
-
-                        if not node_parent_table.startswith(f'{schema}.'):
-                            node_parent_table = f'{schema}.{node_parent_table}'
 
                         for payload in payloads:
                             payload_data = self._payload_data(payload)
@@ -401,32 +396,24 @@ class Sync(Base):
                 # handle case where we insert into a through table
                 root = self.tree.build(nodes[0])
                 for node in traverse_post_order(root):
-                    if table in node.through_tables:
+                    if table in node.relationship.through_tables:
                         if not node.parent:
                             logger.exception(
-                                f'Could not get parent from node: '
-                                f'{node.schema}.{node.table}'
+                                f'Could not get parent from node: {node.name}'
                             )
                             raise
                         # set the parent as the new entity that has changed
                         filters[node.parent.table] = []
-                        parent_model = self.model(
+                        foreign_keys = self.query_builder._get_foreign_keys(
+                            node.parent,
+                            node,
+                        )
+
+                        _table = self._get_table(schema, table)
+                        node_parent_table = self._get_table(
+                            schema,
                             node.parent.table,
-                            node.parent.schema,
                         )
-                        foreign_keys = get_foreign_keys(
-                            parent_model,
-                            model,
-                        )
-
-                        _table = table
-                        if not _table.startswith(f'{schema}.'):
-                            _table = f'{schema}.{table}'
-
-                        node_parent_table = node.parent.table
-
-                        if not node_parent_table.startswith(f'{schema}.'):
-                            node_parent_table = f'{schema}.{node_parent_table}'
 
                         for payload in payloads:
                             payload_data = self._payload_data(payload)
@@ -695,7 +682,7 @@ class Sync(Base):
 
             progress(i + 1, row_count)
 
-            row = transform(self.__name, row, nodes[0])
+            row = transform(row, nodes[0])
             row[META] = get_private_keys(keys)
             if extra:
                 if extra['table'] not in row[META]:
@@ -710,12 +697,20 @@ class Sync(Base):
                 pprint.pprint(row)
                 print('-' * 10)
 
-            yield {
+            doc = {
                 '_id': self.get_doc_id(primary_keys),
                 '_index': index,
                 '_source': row,
             }
 
+            if self._plugins:
+                doc = list(self._plugins.transform([doc]))[0]
+
+            if self.pipeline:
+                doc['pipeline'] = self.pipeline
+
+            yield doc
+
     def sync(self, txmin=None, txmax=None):
         """
         Pull sync all data from database.
@@ -782,6 +777,7 @@ class Sync(Base):
                     f'poll_redis: {payloads}'
                 )
                 self.on_publish(payloads)
+            time.sleep(REDIS_POLL_INTERVAL)
 
     @threaded
     def poll_db(self):
@@ -809,7 +805,7 @@ class Sync(Base):
             ) == ([], [], []):
                 if i % 10 == 0:
                     sys.stdout.write(
-                        f'Polling db {channel}: {j:,} cache items\n'
+                        f'Polling db {channel}: {j:,} items\n'
                     )
                     sys.stdout.flush()
                 i += 1
