@@ -86,8 +86,7 @@ class TestRoot(object):
 
         try:
             sync.es.teardown(index='testdb')
-        except Exception as e:
-            print(f'Exception {e}')
+        except Exception:
             raise
 
         sync.redis._delete()
