@@ -82,8 +82,7 @@ class TestParentSingleChildFkOnParent(object):
 
         try:
             sync.es.teardown(index='testdb')
-        except Exception as e:
-            print(f'Exception {e}')
+        except Exception:
             raise
 
         sync.redis._delete()
@@ -603,7 +602,7 @@ class TestParentSingleChildFkOnParent(object):
 
         with pytest.raises(RelationshipError) as excinfo:
             [doc for doc in sync._sync(nodes, 'testdb')]
-        assert 'Relationship not present on table "public.publisher"' in str(
+        assert 'Relationship not present on "public.publisher"' in str(
             excinfo.value
         )
 
